Court of Appeals of Georgia

New Search

# Inquiry System: Results

Searched the Docket for All Cases Dated: thru
Number of Cases Found:

Case Number | Style | Judgement Date | COA Judgement/Ruling | Web Docket | Opinion/Order
A14D0427 | COURTNEY HARRIS ET AL. v. MINNESOTA LAWYERS MUTUAL INSURANCE COMPANY ET AL. | July 17, 2014 | DISCRETIONARY APPLICATION GRANTED | View | View
A14A1345 | CECIL LAMAR SUMMERVILLE v. THE STATE | July 17, 2014 | DISMISSED | View | View
A14A1744 | ROBERT N. SCOTT v. SAPP'S WRECKER SERVICE ET AL. | July 17, 2014 | WITHDRAWN | View | View
A14E0035 | IN THE INTEREST OF: A. N. T. A CHILD (MOTHER) v. STATE OF GEORGIA | July 17, 2014 | EMERGENCY MOTION GRANTED | View | View